pilas.actores

Package pilas :: Package actores |
[hide private]
[frames] | no frames]

# Source Code for Package pilas.actores

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9
    10  import math
    11
    12  import pilas
    13  import utils
    14  from actor import Actor
    15
    16  todos = []
    17
    18  __doc__ = """
    19  Módulo pilas.actores
    20  ====================
    21
    22  El módulo actores contiene una serie de clases
    23  para representar personajes de videojuegos.
    24
    25  Para crear actores en una escena del juego simplemente
    26  se tiene que crear un nuevo objeto a partir de una
    27  clase.
    28
    29  Por ejemplo, para crear un pongüino podríamos
    30  escribir la siguiente sentencia:
    31
    32      >>> p = pilas.actores.Pingu()
    33
    34  """
    35
    36
    37
    38  from mono import Mono
    39  from ejes import Ejes
    40  from animado import Animado
    41  from animacion import Animacion
    42  from explosion import Explosion
    43  from bomba import Bomba
    44  from pingu import Pingu
    45  from banana import Banana
    46  from texto import Texto
    47  from temporizador import Temporizador
    48  from moneda import Moneda
    49  from pizarra import Pizarra
    50  from pelota import Pelota
    51  from puntaje import Puntaje
    52  from estrella import Estrella
    53  from caja import Caja
    54  from nave import Nave
    55  from navekids import NaveKids
    56  from cursordisparo import CursorDisparo
    57  from piedra import Piedra
    58  from menu import Menu
    59  from opcion import Opcion
    60  from tortuga import Tortuga
    61  from mapa import Mapa
    62  from mapatiled import MapaTiled
    63  from martian import Martian
    64  from boton import Boton
    65  from aceituna import Aceituna
    66  from globo import Globo
    67  from dialogo import Dialogo
    68  from globoelegir import GloboElegir
    69  from pausa import Pausa
    70  from mano import CursorMano
    71  from cooperativista import Cooperativista
    72  from zanahoria import Zanahoria
    73  from energia import Energia
    74  from texto_inferior import TextoInferior
    75  from sonido import Sonido
    76  from personajes_rpg import Calvo
    77  from personajes_rpg import Maton
    78  from pacman import Pacman
    79  from fantasma import Fantasma
    80  from humo import Humo
    81  from proyectil import Bala
    82  from proyectil import Misil
    83  from proyectil import Dinamita
    84  from proyectil import EstrellaNinja
    85  from torreta import Torreta
    86  from ovni import Ovni
    87